#!/usr/bin/ruby -w
#
# $Id: tc_ctime.rb,v 1.4 2004/12/14 03:35:26 ianmacd Exp $

#$: << File.dirname(__FILE__) + "/../lib"

require 'test/unit'
require 'ctime'
require './setup'

class TC_CTimeTest

  DAYS = 3
  START_DATE = DateTime.now
  END_DATE = START_DATE + DAYS


  def test_capabilities

    caps = nil
    assert_nothing_raised { caps = @@ct.capabilities }

    s_keys = %w[ max_date capi_version server_version version ]
    a_keys = %w[ authentication compression unsupported_ical_prop 
		 unsupported_ical_comp ]

    s_keys.each do |k|
      assert_instance_of( String, caps[k],
			  "#{k} is a #{caps[k].class}, not a String" )
    end

    a_keys.each do |k|
      assert_instance_of( Array, caps[k],
			  "#{k} is a #{caps[k].class}, not an Array" )
    end
  end

  def test_open_agenda
    a = @@ct.open_agenda( @@user )
    assert_instance_of( CTime::Agenda, a, "expected a CTime::Agenda object" )
    a.close

    # Test the block form
    @@ct.open_agenda( @@user ) do |a|
      assert_instance_of( CTime::Agenda, a, "expected a CTime::Agenda object" )
    end
  end

  def test_open_close_multiple_agendas
    assert_nothing_raised do
      i = [ @@ct.open_agenda( @@user ) ]
      EXTRA_USERS.each { |u| i << @@ct.open_agenda( u ) }
      i.each { |a| a.close }
    end
  end

  def test_get_events
    a = @@ct.open_agenda( @@user )
    e = a.get_events( START_DATE, END_DATE )
    assert_instance_of( Array, e, "expected an Array" )
    assert_instance_of( CTime::Agenda::Event, e[0],
			"expected a CTime::Agenda::Event" )
    a.close

    # Test the block form
    @@ct.open_agenda( @@user ) do |a|
      a.get_events( START_DATE, END_DATE ) do |e|
	assert_instance_of( CTime::Agenda::Event, e,
			    "expected a CTime::Agenda::Event" )
      end
    end
  end

  def test_set_event
    a = @@ct.open_agenda( @@user )
    e = CTime::Agenda::Event.new( START_DATE, 3600,
	  "Unit test by Ruby/CorporateTime #{CTime::VERSION}",
	  "The white room",
	  "Nothing to see here." )

    uid = a.set_event( e )
    assert_instance_of( String, uid, "failed to set an event" )

    # Now go the other way
    e = a.get_event( uid )
    assert_instance_of( Array, e, "failed to get an event from a UID" )
    assert_instance_of( CTime::Agenda::Event, e[0],
			"expected a CTime::Agenda::Event" )

    assert_nothing_raised { a.delete_event( uid ) }
    a.close
  end

end
